aboutsummaryrefslogtreecommitdiffstats
path: root/src/net/java/sip/communicator/impl/gui/main/contactlist/ContactNode.java
diff options
context:
space:
mode:
authorYana Stamcheva <yana@jitsi.org>2012-08-30 10:56:36 +0000
committerYana Stamcheva <yana@jitsi.org>2012-08-30 10:56:36 +0000
commit9931f4b8004a35f3d5cdfc2b408723d9201f340a (patch)
tree7de598ad7b54f51fef39a7de5fdaf1e672da4834 /src/net/java/sip/communicator/impl/gui/main/contactlist/ContactNode.java
parent325cea15eb5769a79aba5003442e1b1f957fa604 (diff)
downloadjitsi-9931f4b8004a35f3d5cdfc2b408723d9201f340a.zip
jitsi-9931f4b8004a35f3d5cdfc2b408723d9201f340a.tar.gz
jitsi-9931f4b8004a35f3d5cdfc2b408723d9201f340a.tar.bz2
Making the contact list component available from outside the gui bundle.
Diffstat (limited to 'src/net/java/sip/communicator/impl/gui/main/contactlist/ContactNode.java')
-rw-r--r--src/net/java/sip/communicator/impl/gui/main/contactlist/ContactNode.java15
1 files changed, 9 insertions, 6 deletions
diff --git a/src/net/java/sip/communicator/impl/gui/main/contactlist/ContactNode.java b/src/net/java/sip/communicator/impl/gui/main/contactlist/ContactNode.java
index 7fc66d4..c756518 100644
--- a/src/net/java/sip/communicator/impl/gui/main/contactlist/ContactNode.java
+++ b/src/net/java/sip/communicator/impl/gui/main/contactlist/ContactNode.java
@@ -8,6 +8,8 @@ package net.java.sip.communicator.impl.gui.main.contactlist;
import javax.swing.tree.*;
+import net.java.sip.communicator.service.gui.*;
+
/**
* The <tt>ContactNode</tt> is a <tt>ContactListNode</tt> corresponding to a
* given <tt>UIContact</tt>.
@@ -31,21 +33,22 @@ public class ContactNode
/**
* Creates a <tt>ContactNode</tt> by specifying the corresponding
* <tt>contact</tt>.
* @param contact the <tt>UIContact</tt> corresponding to this node
*/
- public ContactNode(UIContact contact)
+ public ContactNode(UIContactImpl contact)
{
super(contact);
this.contact = contact;
}
/**
* Returns the corresponding <tt>UIContact</tt>.
* @return the corresponding <tt>UIContact</tt>
*/
- public UIContact getContactDescriptor()
+ public UIContactImpl getContactDescriptor()
{
- return (UIContact) getUserObject();
+ return (UIContactImpl) getUserObject();
}
/**
@@ -31,21 +33,22 @@ public class ContactNode
* Creates a <tt>ContactNode</tt> by specifying the corresponding
* <tt>contact</tt>.
- * @param contact the <tt>UIContact</tt> corresponding to this node
+ * @param contact the <tt>UIContactImpl</tt> corresponding to this node
*/
@@ -31,21 +33,22 @@ public class ContactNode
}
/**
- * Returns the corresponding <tt>UIContact</tt>.
- * @return the corresponding <tt>UIContact</tt>
+ * Returns the corresponding <tt>UIContactImpl</tt>.
+ *
+ * @return the corresponding <tt>UIContactImpl</tt>
*/